seqtools.join_subsequences_by_sign_of_subsequence_elements
==========================================================

.. autofunction:: abjad.tools.seqtools.join_subsequences_by_sign_of_subsequence_elements
